function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { Animated, Platform, StyleSheet, TouchableWithoutFeedback, View } from 'react-native';
import color from 'color';
import Icon from './Icon';
import Surface from './Surface';
import Text from './Typography/Text';
import TouchableRipple from './TouchableRipple';
import { withTheme } from '../core/theming';
import { black, white } from '../styles/colors';

/**
 * Chips can be used to display entities in small blocks.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/chip-1.png" />
 *     <figcaption>Flat chip</figcaption>
 *   </figure>
 *   <figure>
 *     <img class="medium" src="screenshots/chip-2.png" />
 *     <figcaption>Outlined chip</figcaption>
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { Chip } from 'react-native-paper';
 *
 * const MyComponent = () => (
 *   <Chip icon="information" onPress={() => console.log('Pressed')}>Example Chip</Chip>
 * );
 *
 * export default MyComponent;
 * ```
 */
class Chip extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      elevation: new Animated.Value(0)
    });

    _defineProperty(this, "handlePressIn", () => {
      const {
        scale
      } = this.props.theme.animation;
      Animated.timing(this.state.elevation, {
        toValue: 4,
        duration: 200 * scale,
        useNativeDriver: false
      }).start();
    });

    _defineProperty(this, "handlePressOut", () => {
      const {
        scale
      } = this.props.theme.animation;
      Animated.timing(this.state.elevation, {
        toValue: 0,
        duration: 150 * scale,
        useNativeDriver: false
      }).start();
    });
  }

  render() {
    const _this$props = this.props,
          {
      mode,
      children,
      icon,
      avatar,
      selected,
      disabled,
      accessibilityLabel,
      onPress,
      onLongPress,
      onClose,
      textStyle,
      style,
      theme,
      testID,
      selectedColor
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["mode", "children", "icon", "avatar", "selected", "disabled", "accessibilityLabel", "onPress", "onLongPress", "onClose", "textStyle", "style", "theme", "testID", "selectedColor"]);

    const {
      dark,
      colors
    } = theme;
    const {
      backgroundColor = mode === 'outlined' ? colors.surface : dark ? '#383838' : '#ebebeb',
      borderRadius = 16
    } = StyleSheet.flatten(style) || {};
    const borderColor = mode === 'outlined' ? color(selectedColor !== undefined ? selectedColor : color(dark ? white : black)).alpha(0.29).rgb().string() : backgroundColor;
    const textColor = disabled ? colors.disabled : color(selectedColor !== undefined ? selectedColor : colors.text).alpha(0.87).rgb().string();
    const iconColor = disabled ? colors.disabled : color(selectedColor !== undefined ? selectedColor : colors.text).alpha(0.54).rgb().string();
    const selectedBackgroundColor = (dark ? color(backgroundColor).lighten(mode === 'outlined' ? 0.2 : 0.4) : color(backgroundColor).darken(mode === 'outlined' ? 0.08 : 0.2)).rgb().string();
    const underlayColor = selectedColor ? color(selectedColor).fade(0.5).rgb().string() : selectedBackgroundColor;
    const accessibilityTraits = ['button'];
    const accessibilityStates = [];

    if (selected) {
      accessibilityTraits.push('selected');
      accessibilityStates.push('selected');
    }

    if (disabled) {
      accessibilityTraits.push('disabled');
      accessibilityStates.push('disabled');
    }

    return /*#__PURE__*/React.createElement(Surface, _extends({
      style: [styles.container, {
        elevation: Platform.OS === 'android' ? this.state.elevation : 0,
        backgroundColor: selected ? selectedBackgroundColor : backgroundColor,
        borderColor,
        borderRadius
      }, style]
    }, rest), /*#__PURE__*/React.createElement(TouchableRipple, {
      borderless: true,
      delayPressIn: 0,
      style: {
        borderRadius
      },
      onPress: onPress,
      onLongPress: onLongPress,
      onPressIn: this.handlePressIn,
      onPressOut: this.handlePressOut,
      underlayColor: underlayColor,
      disabled: disabled,
      accessibilityLabel: accessibilityLabel,
      accessibilityTraits: accessibilityTraits,
      accessibilityComponentType: "button",
      accessibilityRole: "button",
      accessibilityStates: accessibilityStates,
      testID: testID
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.content
    }, avatar && !icon ? /*#__PURE__*/React.createElement(View, {
      style: [styles.avatarWrapper, disabled && {
        opacity: 0.26
      }]
    }, /*#__PURE__*/React.isValidElement(avatar) ?
    /*#__PURE__*/

    /* $FlowFixMe */
    React.cloneElement(avatar, {
      /* $FlowFixMe */
      style: [styles.avatar, avatar.props.style]
    }) : avatar) : null, icon || selected ? /*#__PURE__*/React.createElement(View, {
      style: [styles.icon, avatar ? [styles.avatar, styles.avatarSelected] : null]
    }, /*#__PURE__*/React.createElement(Icon, {
      source: icon || 'check',
      color: avatar ? white : iconColor,
      size: 18
    })) : null, /*#__PURE__*/React.createElement(Text, {
      numberOfLines: 1,
      style: [styles.text, _objectSpread(_objectSpread({}, theme.fonts.regular), {}, {
        color: textColor,
        marginRight: onClose ? 4 : 8,
        marginLeft: avatar || icon || selected ? 4 : 8
      }), textStyle]
    }, children), onClose ? /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
      onPress: onClose,
      accessibilityTraits: "button",
      accessibilityComponentType: "button"
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.icon
    }, /*#__PURE__*/React.createElement(Icon, {
      source: "close-circle",
      size: 16,
      color: iconColor
    }))) : null)));
  }

}

_defineProperty(Chip, "defaultProps", {
  mode: 'flat',
  disabled: false,
  selected: false
});

const styles = StyleSheet.create({
  container: {
    borderWidth: StyleSheet.hairlineWidth,
    borderStyle: 'solid'
  },
  content: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingHorizontal: 4
  },
  icon: {
    padding: 4
  },
  text: {
    minHeight: 24,
    lineHeight: 24,
    textAlignVertical: 'center',
    marginVertical: 4
  },
  avatar: {
    width: 24,
    height: 24,
    borderRadius: 12
  },
  avatarWrapper: {
    marginRight: 4
  },
  avatarSelected: {
    position: 'absolute',
    top: 4,
    left: 4,
    backgroundColor: 'rgba(0, 0, 0, .29)'
  }
});
export default withTheme(Chip);
//# sourceMappingURL=Chip.js.map