function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
export const ToggleButtonGroupContext = /*#__PURE__*/React.createContext(null);
/**
 * Toggle group allows to control a group of toggle buttons.</br>
 * It doesn't change the appearance of the toggle buttons. If you want to group them in a row, checkout <a href="/toggle-button-row.html">`ToggleButton.Row`</a>.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/toggle-button-group.gif" />
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { ToggleButton } from 'react-native-paper';
 *
 * const MyComponent = () => {
 *   const [value, setValue] = React.useState('left');
 *
 *   return (
 *     <ToggleButton.Group
 *       onValueChange={value => setValue(value)}
 *       value={value}>
 *       <ToggleButton icon="format-align-left" value="left" />
 *       <ToggleButton icon="format-align-right" value="right" />
 *     </ToggleButton.Group>
 *   );
 * };
 *
 * export default MyComponent;
 *```
 */

class ToggleButtonGroup extends React.Component {
  render() {
    const {
      value,
      onValueChange,
      children
    } = this.props;
    return /*#__PURE__*/React.createElement(ToggleButtonGroupContext.Provider, {
      value: {
        value,
        onValueChange
      }
    }, children);
  }

}

_defineProperty(ToggleButtonGroup, "displayName", 'ToggleButton.Group');

export default ToggleButtonGroup;
//# sourceMappingURL=ToggleButtonGroup.js.map