function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as React from 'react';
import { TouchableWithoutFeedback, View, StyleSheet } from 'react-native';
import color from 'color';
import { withTheme } from '../../core/theming';

/**
 * A wrapper for views that should respond to touches.
 * Provides a material "ink ripple" interaction effect for supported platforms (>= Android Lollipop).
 * On unsupported platforms, it falls back to a highlight effect.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/touchable-ripple.gif" />
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { View } from 'react-native';
 * import { Text, TouchableRipple } from 'react-native-paper';
 *
 * const MyComponent = () => (
 *   <TouchableRipple
 *     onPress={() => console.log('Pressed')}
 *     rippleColor="rgba(0, 0, 0, .32)"
 *   >
 *     <Text>Press anywhere</Text>
 *   </TouchableRipple>
 * );
 *
 * export default MyComponent;
 * ```
 */
class TouchableRipple extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "handlePressIn", e => {
      const {
        centered,
        rippleColor,
        onPressIn,
        theme
      } = this.props;
      onPressIn === null || onPressIn === void 0 ? void 0 : onPressIn(e);
      const {
        dark,
        colors
      } = theme;
      const calculatedRippleColor = rippleColor || color(colors.text).alpha(dark ? 0.32 : 0.2).rgb().string();
      const button = e.currentTarget;
      const style = window.getComputedStyle(button);
      const dimensions = button.getBoundingClientRect();
      let touchX;
      let touchY;

      if (centered) {
        touchX = dimensions.width / 2;
        touchY = dimensions.height / 2;
      } else {
        var _touches$, _touch$pageX, _touch$pageY;

        const {
          changedTouches,
          touches
        } = e.nativeEvent;
        const touch = (_touches$ = touches === null || touches === void 0 ? void 0 : touches[0]) !== null && _touches$ !== void 0 ? _touches$ : changedTouches === null || changedTouches === void 0 ? void 0 : changedTouches[0];
        const startX = (_touch$pageX = touch.pageX) !== null && _touch$pageX !== void 0 ? _touch$pageX : e.pageX;
        const startY = (_touch$pageY = touch.pageY) !== null && _touch$pageY !== void 0 ? _touch$pageY : e.pageY;
        touchX = startX - dimensions.left;
        touchY = startY - dimensions.top;
      } // Get the size of the button to determine how big the ripple should be


      const size = centered ? // If ripple is always centered, we don't need to make it too big
      Math.min(dimensions.width, dimensions.height) * 1.25 : // Otherwise make it twice as big so clicking on one end spreads ripple to other
      Math.max(dimensions.width, dimensions.height) * 2; // Create a container for our ripple effect so we don't need to change the parent's style

      const container = document.createElement('span');
      container.setAttribute('data-paper-ripple', '');
      Object.assign(container.style, {
        position: 'absolute',
        pointerEvents: 'none',
        top: '0',
        left: '0',
        right: '0',
        bottom: '0',
        borderTopLeftRadius: style.borderTopLeftRadius,
        borderTopRightRadius: style.borderTopRightRadius,
        borderBottomRightRadius: style.borderBottomRightRadius,
        borderBottomLeftRadius: style.borderBottomLeftRadius,
        overflow: centered ? 'visible' : 'hidden'
      }); // Create span to show the ripple effect

      const ripple = document.createElement('span');
      Object.assign(ripple.style, {
        position: 'absolute',
        pointerEvents: 'none',
        backgroundColor: calculatedRippleColor,
        borderRadius: '50%',

        /* Transition configuration */
        transitionProperty: 'transform opacity',
        transitionDuration: "".concat(Math.min(size * 1.5, 350), "ms"),
        transitionTimingFunction: 'linear',
        transformOrigin: 'center',

        /* We'll animate these properties */
        transform: 'translate3d(-50%, -50%, 0) scale3d(0.1, 0.1, 0.1)',
        opacity: '0.5',
        // Position the ripple where cursor was
        left: "".concat(touchX, "px"),
        top: "".concat(touchY, "px"),
        width: "".concat(size, "px"),
        height: "".concat(size, "px")
      }); // Finally, append it to DOM

      container.appendChild(ripple);
      button.appendChild(container); // rAF runs in the same frame as the event handler
      // Use double rAF to ensure the transition class is added in next frame
      // This will make sure that the transition animation is triggered

      requestAnimationFrame(() => {
        requestAnimationFrame(() => {
          Object.assign(ripple.style, {
            transform: 'translate3d(-50%, -50%, 0) scale3d(1, 1, 1)',
            opacity: '1'
          });
        });
      });
    });

    _defineProperty(this, "handlePressOut", e => {
      this.props.onPressOut && this.props.onPressOut(e);
      const containers = e.currentTarget.querySelectorAll('[data-paper-ripple]');
      requestAnimationFrame(() => {
        requestAnimationFrame(() => {
          containers.forEach(container => {
            // @ts-ignore
            const ripple = container.firstChild; // @ts-ignore

            Object.assign(ripple.style, {
              transitionDuration: '250ms',
              opacity: 0
            }); // Finally remove the span after the transition

            setTimeout(() => {
              // @ts-ignore
              const {
                parentNode
              } = container;

              if (parentNode) {
                parentNode.removeChild(container);
              }
            }, 500);
          });
        });
      });
    });
  }

  render() {
    /* eslint-disable @typescript-eslint/no-unused-vars */
    const _this$props = this.props,
          {
      style,
      background,
      borderless,
      disabled: disabledProp,
      rippleColor,
      underlayColor,
      children,
      theme
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["style", "background", "borderless", "disabled", "rippleColor", "underlayColor", "children", "theme"]);
    /* eslint-enable @typescript-eslint/no-unused-vars */


    const disabled = disabledProp || !this.props.onPress;
    return /*#__PURE__*/React.createElement(TouchableWithoutFeedback, _extends({}, rest, {
      onPressIn: this.handlePressIn,
      onPressOut: this.handlePressOut,
      disabled: disabled
    }), /*#__PURE__*/React.createElement(View, {
      style: [styles.touchable, borderless && styles.borderless, style]
    }, React.Children.only(children)));
  }

}

_defineProperty(TouchableRipple, "defaultProps", {
  borderless: false
});

_defineProperty(TouchableRipple, "supported", true);

const styles = StyleSheet.create({
  touchable: {
    position: 'relative'
  },
  borderless: {
    overflow: 'hidden'
  }
});
export default withTheme(TouchableRipple);
//# sourceMappingURL=index.js.map